#!/usr/bin/env python3
"""
Simple Packet Sniffer
Parameters:
    - IP: Interface IP to sniff on
Requires: scapy package and admin/root privileges
"""
from scapy.all import *
import argparse
import sys

def packet_callback(packet):
    if IP in packet:
        src_ip = packet[IP].src
        dst_ip = packet[IP].dst
        proto = packet[IP].proto
        
        # Convert protocol number to name
        proto_name = {1: "ICMP", 6: "TCP", 17: "UDP"}.get(proto, str(proto))
        
        print(f"Protocol: {proto_name:5} {src_ip:15} -> {dst_ip:15}", end=" ")
        
        # Additional protocol-specific information
        if TCP in packet:
            print(f"Port: {packet[TCP].sport} -> {packet[TCP].dport}")
        elif UDP in packet:
            print(f"Port: {packet[UDP].sport} -> {packet[UDP].dport}")
        elif ICMP in packet:
            print(f"Type: {packet[ICMP].type}")
        else:
            print()

def start_sniffer(ip):
    try:
        print(f"Starting packet sniffer on interface with IP {ip}")
        print("Press Ctrl+C to stop...")
        
        # Start sniffing
        sniff(filter=f"host {ip}", prn=packet_callback)
    except Exception as e:
        print(f"Error: {str(e)}")
        sys.exit(1)

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="Simple Packet Sniffer")
    parser.add_argument("ip", help="Interface IP to sniff on")
    args = parser.parse_args()
    
    start_sniffer(args.ip)
